==> haskell-bytestring-encoding-0.1.1.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-encoding
version:              0.1.1.0
visibility:           public
id:                   bytestring-encoding-0.1.1.0-9ZPmIdJWooM4qfv2FLcxMw
key:                  bytestring-encoding-0.1.1.0-9ZPmIdJWooM4qfv2FLcxMw
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  7bcd36b8844b61b81e304f2250451b78
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/bytestring-encoding-0.1.1.0

hs-libraries:         HSbytestring-encoding-0.1.1.0-9ZPmIdJWooM4qfv2FLcxMw
depends:              base-4.15.0.0 bytestring-0.10.12.1 text-1.2.4.1
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-encoding-0.1.1.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-encoding
version:              0.1.1.0
visibility:           public
id:                   bytestring-encoding-0.1.1.0-2SpEmtA48L245DyKbusMOM
key:                  bytestring-encoding-0.1.1.0-2SpEmtA48L245DyKbusMOM
license:              BSD-3-Clause
copyright:            2018 Masahiro Sakai
maintainer:           masahiro.sakai@gmail.com
author:               Masahiro Sakai
homepage:             https://github.com/msakai/bytestring-encoding#readme
synopsis:             ByteString ↔ Text converter based on GHC.IO.Encoding
description:
    Please see the README on GitHub at <https://github.com/msakai/bytestring-encoding#readme>

category:             Data, Text
abi:                  d8e4b8b9cbde68b2500ada58dedf0251
exposed:              True
exposed-modules:
    Data.ByteString.Encoding Data.ByteString.Lazy.Encoding
    Data.ByteString.Lazy.Encoding.Internal

hidden-modules:       Paths_bytestring_encoding
import-dirs:          /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/bytestring-encoding-0.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/bytestring-encoding-0.1.1.0

hs-libraries:         HSbytestring-encoding-0.1.1.0-2SpEmtA48L245DyKbusMOM
depends:              base-4.15.0.0 bytestring-0.10.12.1 text-1.2.4.1
haddock-interfaces:
    /usr/share/doc/haskell-bytestring-encoding/html/bytestring-encoding.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
